@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -21,7 +21,7 @@ sub new {
 
 	my %lwp_options = %{ $opt{lwp_options} // { timeout => 10 } };
 
-	my $ua = LWP::UserAgent->new( %{ $opt{lwp_options} } );
+	my $ua = LWP::UserAgent->new(%lwp_options);
 
 	if ( not $opt{station} ) {
 		confess('station flag must be passed');
@@ -402,7 +402,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -447,7 +447,7 @@ non-negative integer is accepted.
 =item B<lwp_options> => I<\%hashref>
 
 Passed on to C<< LWP::UserAgent->new >>. Defaults to C<< { timeout => 10 } >>,
-you can use an empty hashref to override it.
+you can use an empty hashref to unset the default.
 
 =item B<station> => I<stationcode>
 
@@ -502,6 +502,10 @@ Many backend features are not yet exposed.
 db-iris(1), Travel::Status::DE::IRIS::Result(3pm),
 Travel::Status::DE::IRIS::Stations(3pm)
 
+=head1 REPOSITORY
+
+L<https://github.com/derf/Travel-Status-DE-IRIS>
+
 =head1 AUTHOR
 
 Copyright (C) 2013-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
