@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -62,12 +62,13 @@ my %translation = (
 	57 => 'Zusätzlicher Halt',
 	58 => 'Umleitung',                                          # ?
 	59 => 'Schnee und Eis',
-	60 => 'Reduzierte Geschwindigkeit wegen Sturm(?)',
+	60 => 'Reduzierte Geschwindigkeit wegen Sturm',
 	61 => 'Türstörung',
 	62 => 'Behobene technische Störung am Zug',
 	63 => 'Technische Untersuchung am Zug',
 	64 => 'Weichenstörung',
 	65 => 'Erdrutsch',
+	70 => 'Kein WLAN(?)', # ?
 	73 => 'Mehrzweckabteil vorne',
 	74 => 'Mehrzweckabteil hinten',
 	75 => '1. Klasse vorne',
@@ -88,8 +89,8 @@ my %translation = (
 	93 => 'Fehlende oder gestörte behindertengerechte Einrichtung',
 	94 => 'Ersatzbewirtschaftung',
 	95 => 'Ohne behindertengerechtes WC',
-	96 => 'Der Zug ist überbesetzt',
-	97 => 'Der Zug ist überbesetzt',
+	96 => 'Der Zug ist stark überbesetzt', # r 97
+	97 => 'Der Zug ist überbesetzt', # r 96
 	98 => 'Sonstige Qualitätsmängel',
 	99 => 'Verzögerungen im Betriebsablauf',
 );
@@ -633,7 +634,7 @@ sub route_interesting {
 	$max_parts //= 3;
 
 	for my $stop (@via) {
-		if ( $stop =~ m{ ?Hbf}o ) {
+		if ( $stop =~ m{ Hbf | Flughafen }ox ) {
 			push( @via_main, $stop );
 		}
 	}
@@ -704,6 +705,8 @@ sub superseded_messages {
 	my %superseded = (
 		84 => [ 80, 82, 83, 85 ],
 		88 => [ 80, 82, 83, 85, 86, 87, 90, 91, 92, 93, 96, 97, 98 ],
+		96 => [ 97 ],
+		97 => [ 96 ],
 	);
 
 	return @{ $superseded{$msg} // [] };
@@ -750,7 +753,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -1187,8 +1190,7 @@ Source: Correlation between IRIS and DB RIS (bahn.de).
 
 =item d 60 : "Reduzierte Geschwindigkeit wegen Sturm"
 
-Source: Correlation between IRIS and DB RIS (bahn.de). Needs further
-verification.
+Source: Correlation between IRIS and DB RIS (bahn.de).
 
 =item d 61 : "TE<uuml>rstE<ouml>rung"
 
@@ -1208,6 +1210,10 @@ Source: correlation between IRIS and DB RIS (bahn.de).
 
 Source: correlation between IRIS and DB RIS (bahn.de).
 
+=item q 70 : "Kein WLAN"
+
+Uncertain. Source: correlation between IRIS and DB RIS (bahn.de).
+
 =item q 73 : "Mehrzweckabteil vorne"
 
 Source: correlation between IRIS and DB RIS (bahn.de).
@@ -1297,7 +1303,7 @@ Estimated from a comparison with bahn.de/ris messages. Needs to be verified.
 
 Estimated from a comparison with bahn.de/iris messages.
 
-=item q 96 : "Der Zug ist E<uuml>berbesetzt"
+=item q 96 : "Der Zug ist stark E<uuml>berbesetzt"
 
 Verified by L<https://iris.noncd.db.de/irisWebclient/Configuration>.
 
